@@ -1,7 +1,7 @@
 package App::ListNewCPANDists;
 
-our $DATE = '2017-07-01'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-07-02'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -201,10 +201,13 @@ sub list_new_cpan_dists {
     my $api_res = _json_decode($res->{content});
     my %dists;
     my @res;
+    my $num_hits = @{ $api_res->{hits}{hits} };
+    my $i = 0;
     for my $hit (@{ $api_res->{hits}{hits} }) {
+        $i++;
         my $dist = $hit->{fields}{distribution};
         next if $dists{ $dist }++;
-        log_trace("Got distribution %s", $dist);
+        log_trace("[#%d/%d] Got distribution %s", $i, $num_hits, $dist);
         # find the first release of this distribution
         my $relinfo = _get_dist_first_release($state, $dist);
         unless ($relinfo->{time} >= $args{from_time}->epoch &&
@@ -336,7 +339,7 @@ App::ListNewCPANDists - List new CPAN distributions in a given time period
 
 =head1 VERSION
 
-This document describes version 0.004 of App::ListNewCPANDists (from Perl distribution App-ListNewCPANDists), released on 2017-07-01.
+This document describes version 0.005 of App::ListNewCPANDists (from Perl distribution App-ListNewCPANDists), released on 2017-07-02.
 
 =head1 FUNCTIONS
 
